API 
===

lacbox.io
---------

.. automodule:: lacbox.io
    :members:

lacbox.rotor_design.aero_design
-------------------------------

.. automodule:: lacbox.rotor_design.aero_design
    :members: single_point_design, get_design_functions, get_design_functions_1MW

lacbox.rotor_design.structural_scaling
--------------------------------------

.. automodule:: lacbox.rotor_design.structural_scaling
    :members: scale_ST_data

lacbox.rotor_design.utils
-------------------------

.. automodule:: lacbox.rotor_design.utils
    :members: root_chord, min_tc_chord, max_twist, interpolator

lacbox.htc.HTCFile
------------------

.. autoclass:: lacbox.htc.HTCFile
   :members: add_mann_turbulence, save, set_name, set_time

lacbox.postprocess
------------------

.. automodule:: lacbox.postprocess
    :members: process_statistics